==> snapd-glib_0.8.orig.tar.xz: snapd-glib-0.8/snapd-glib/snapd-enum-types.c <==

/* Generated data (by glib-mkenums) */

/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#include "config.h"
#include "snapd-enum-types.h"

/* enumerations from "./snapd-client.h" */
#include "./snapd-client.h"

GType
snapd_client_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_CLIENT_ERROR_CONNECTION_FAILED, "SNAPD_CLIENT_ERROR_CONNECTION_FAILED", "connection-failed" },
        { SNAPD_CLIENT_ERROR_WRITE_ERROR, "SNAPD_CLIENT_ERROR_WRITE_ERROR", "write-error" },
        { SNAPD_CLIENT_ERROR_READ_ERROR, "SNAPD_CLIENT_ERROR_READ_ERROR", "read-error" },
        { SNAPD_CLIENT_ERROR_PARSE_ERROR, "SNAPD_CLIENT_ERROR_PARSE_ERROR", "parse-error" },
        { SNAPD_CLIENT_ERROR_GENERAL_ERROR, "SNAPD_CLIENT_ERROR_GENERAL_ERROR", "general-error" },
        { SNAPD_CLIENT_ERROR_LOGIN_REQUIRED, "SNAPD_CLIENT_ERROR_LOGIN_REQUIRED", "login-required" },
        { SNAPD_CLIENT_ERROR_INVALID_AUTH_DATA, "SNAPD_CLIENT_ERROR_INVALID_AUTH_DATA", "invalid-auth-data" },
        { SNAPD_CLIENT_ERROR_TWO_FACTOR_REQUIRED, "SNAPD_CLIENT_ERROR_TWO_FACTOR_REQUIRED", "two-factor-required" },
        { SNAPD_CLIENT_ERROR_TWO_FACTOR_FAILED, "SNAPD_CLIENT_ERROR_TWO_FACTOR_FAILED", "two-factor-failed" },
        { SNAPD_CLIENT_ERROR_BAD_REQUEST, "SNAPD_CLIENT_ERROR_BAD_REQUEST", "bad-request" },
        { SNAPD_CLIENT_ERROR_LAST, "SNAPD_CLIENT_ERROR_LAST", "last" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdClientError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_find_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SNAPD_FIND_FLAGS_NONE, "SNAPD_FIND_FLAGS_NONE", "none" },
        { SNAPD_FIND_FLAGS_MATCH_NAME, "SNAPD_FIND_FLAGS_MATCH_NAME", "match-name" },
        { SNAPD_FIND_FLAGS_SELECT_PRIVATE, "SNAPD_FIND_FLAGS_SELECT_PRIVATE", "select-private" },
        { SNAPD_FIND_FLAGS_SELECT_REFRESH, "SNAPD_FIND_FLAGS_SELECT_REFRESH", "select-refresh" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SnapdFindFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-snap.h" */
#include "./snapd-snap.h"

GType
snapd_confinement_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_CONFINEMENT_UNKNOWN, "SNAPD_CONFINEMENT_UNKNOWN", "unknown" },
        { SNAPD_CONFINEMENT_STRICT, "SNAPD_CONFINEMENT_STRICT", "strict" },
        { SNAPD_CONFINEMENT_DEVMODE, "SNAPD_CONFINEMENT_DEVMODE", "devmode" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdConfinement"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_TYPE_UNKNOWN, "SNAPD_SNAP_TYPE_UNKNOWN", "unknown" },
        { SNAPD_SNAP_TYPE_APP, "SNAPD_SNAP_TYPE_APP", "app" },
        { SNAPD_SNAP_TYPE_KERNEL, "SNAPD_SNAP_TYPE_KERNEL", "kernel" },
        { SNAPD_SNAP_TYPE_GADGET, "SNAPD_SNAP_TYPE_GADGET", "gadget" },
        { SNAPD_SNAP_TYPE_OS, "SNAPD_SNAP_TYPE_OS", "os" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_status_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_STATUS_UNKNOWN, "SNAPD_SNAP_STATUS_UNKNOWN", "unknown" },
        { SNAPD_SNAP_STATUS_AVAILABLE, "SNAPD_SNAP_STATUS_AVAILABLE", "available" },
        { SNAPD_SNAP_STATUS_PRICED, "SNAPD_SNAP_STATUS_PRICED", "priced" },
        { SNAPD_SNAP_STATUS_INSTALLED, "SNAPD_SNAP_STATUS_INSTALLED", "installed" },
        { SNAPD_SNAP_STATUS_ACTIVE, "SNAPD_SNAP_STATUS_ACTIVE", "active" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapStatus"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* Generated data ends here */

==> snapd-glib_0.10.orig.tar.xz: snapd-glib-0.10/snapd-glib/snapd-enum-types.c <==

/* Generated data (by glib-mkenums) */

/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#include "config.h"
#include "snapd-enum-types.h"

/* enumerations from "./snapd-client.h" */
#include "./snapd-client.h"

GType
snapd_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_ERROR_CONNECTION_FAILED, "SNAPD_ERROR_CONNECTION_FAILED", "connection-failed" },
        { SNAPD_ERROR_WRITE_ERROR, "SNAPD_ERROR_WRITE_ERROR", "write-error" },
        { SNAPD_ERROR_READ_ERROR, "SNAPD_ERROR_READ_ERROR", "read-error" },
        { SNAPD_ERROR_PARSE_ERROR, "SNAPD_ERROR_PARSE_ERROR", "parse-error" },
        { SNAPD_ERROR_GENERAL_ERROR, "SNAPD_ERROR_GENERAL_ERROR", "general-error" },
        { SNAPD_ERROR_LOGIN_REQUIRED, "SNAPD_ERROR_LOGIN_REQUIRED", "login-required" },
        { SNAPD_ERROR_INVALID_AUTH_DATA, "SNAPD_ERROR_INVALID_AUTH_DATA", "invalid-auth-data" },
        { SNAPD_ERROR_TWO_FACTOR_REQUIRED, "SNAPD_ERROR_TWO_FACTOR_REQUIRED", "two-factor-required" },
        { SNAPD_ERROR_TWO_FACTOR_FAILED, "SNAPD_ERROR_TWO_FACTOR_FAILED", "two-factor-failed" },
        { SNAPD_ERROR_BAD_REQUEST, "SNAPD_ERROR_BAD_REQUEST", "bad-request" },
        { SNAPD_ERROR_PERMISSION_DENIED, "SNAPD_ERROR_PERMISSION_DENIED", "permission-denied" },
        { SNAPD_ERROR_LAST, "SNAPD_ERROR_LAST", "last" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_find_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SNAPD_FIND_FLAGS_NONE, "SNAPD_FIND_FLAGS_NONE", "none" },
        { SNAPD_FIND_FLAGS_MATCH_NAME, "SNAPD_FIND_FLAGS_MATCH_NAME", "match-name" },
        { SNAPD_FIND_FLAGS_SELECT_PRIVATE, "SNAPD_FIND_FLAGS_SELECT_PRIVATE", "select-private" },
        { SNAPD_FIND_FLAGS_SELECT_REFRESH, "SNAPD_FIND_FLAGS_SELECT_REFRESH", "select-refresh" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SnapdFindFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./snapd-snap.h" */
#include "./snapd-snap.h"

GType
snapd_confinement_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_CONFINEMENT_UNKNOWN, "SNAPD_CONFINEMENT_UNKNOWN", "unknown" },
        { SNAPD_CONFINEMENT_STRICT, "SNAPD_CONFINEMENT_STRICT", "strict" },
        { SNAPD_CONFINEMENT_DEVMODE, "SNAPD_CONFINEMENT_DEVMODE", "devmode" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdConfinement"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_TYPE_UNKNOWN, "SNAPD_SNAP_TYPE_UNKNOWN", "unknown" },
        { SNAPD_SNAP_TYPE_APP, "SNAPD_SNAP_TYPE_APP", "app" },
        { SNAPD_SNAP_TYPE_KERNEL, "SNAPD_SNAP_TYPE_KERNEL", "kernel" },
        { SNAPD_SNAP_TYPE_GADGET, "SNAPD_SNAP_TYPE_GADGET", "gadget" },
        { SNAPD_SNAP_TYPE_OS, "SNAPD_SNAP_TYPE_OS", "os" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
snapd_snap_status_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SNAPD_SNAP_STATUS_UNKNOWN, "SNAPD_SNAP_STATUS_UNKNOWN", "unknown" },
        { SNAPD_SNAP_STATUS_AVAILABLE, "SNAPD_SNAP_STATUS_AVAILABLE", "available" },
        { SNAPD_SNAP_STATUS_PRICED, "SNAPD_SNAP_STATUS_PRICED", "priced" },
        { SNAPD_SNAP_STATUS_INSTALLED, "SNAPD_SNAP_STATUS_INSTALLED", "installed" },
        { SNAPD_SNAP_STATUS_ACTIVE, "SNAPD_SNAP_STATUS_ACTIVE", "active" },
        { 0, NULL, NULL }
      };

      GType g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SnapdSnapStatus"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* Generated data ends here */
